Package: tranSurv
Title: Transformation-Based Regression under Dependent Truncation
Version: 1.2.4
Authors@R: c(person(given = "Sy Han (Steven)", family = "Chiou",
	     email = "schiou@smu.edu",
	     role = c("aut", "cre")),
	     person(given = "Jing", family = "Qian",
	     email = "qian@schoolph.umass.edu", role = "aut"))
Description: A latent, quasi-independent truncation time is assumed to be linked with the observed dependent truncation time, the event time, and an unknown transformation parameter via a structural transformation model. The transformation parameter is chosen to minimize the conditional Kendall's tau (Martin and Betensky, 2005) <doi:10.1198/016214504000001538> or the regression coefficient estimates (Jones and Crowley, 1992) <doi:10.2307/2336782>. The marginal distribution for the truncation time and the event time are completely left unspecified. The methodology is applied to survival curve estimation and regression analysis.
License: GPL (>= 3)
URL: https://github.com/stc04003/tranSurv
BugReports: https://github.com/stc04003/tranSurv/issues
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: rootSolve, truncSP, survival, SQUAREM, methods
Suggests: MASS, boot
NeedsCompilation: yes
Packaged: 2025-09-22 13:51:50 UTC; schiou
Author: Sy Han (Steven) Chiou [aut, cre],
  Jing Qian [aut]
Maintainer: Sy Han (Steven) Chiou <schiou@smu.edu>
Repository: CRAN
Date/Publication: 2025-09-22 14:20:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 20:50:43 UTC; unix
Archs: tranSurv.so.dSYM
