# Generated by roxygen2: do not edit by hand

S3method(coef,trReg)
S3method(plot,trReg)
S3method(plot,trSurvfit)
S3method(print,cKendall)
S3method(print,pmcc)
S3method(print,trReg)
S3method(print,trSurvfit)
S3method(print,trgof)
S3method(summary,trReg)
export(Surv)
export(cKendall)
export(gof)
export(is.Surv)
export(kendall)
export(pmcc)
export(trReg)
export(trSurv.control)
export(trSurvfit)
export(wKendall)
importFrom(SQUAREM,squarem)
importFrom(graphics,abline)
importFrom(graphics,boxplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(methods,getClass)
importFrom(methods,is)
importFrom(parallel,clusterExport)
importFrom(parallel,makeCluster)
importFrom(parallel,parSapply)
importFrom(parallel,stopCluster)
importFrom(rootSolve,uniroot.all)
importFrom(stats,approx)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,lm)
importFrom(stats,model.matrix)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,printCoefmat)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(stats,update)
importFrom(survival,Surv)
importFrom(survival,coxph)
importFrom(survival,coxph.control)
importFrom(survival,is.Surv)
importFrom(survival,survfit)
importFrom(truncSP,lt)
importFrom(utils,combn)
importFrom(utils,head)
useDynLib(tranSurv, .registration = TRUE)
